from .aca import disp_aca, strain_aca  # noqa: F401
from .fullspace import (  # noqa: F401
    disp,
    disp_block,
    disp_free,
    disp_matrix,
    py_disp,
    strain,
    strain_block,
    strain_free,
    strain_matrix,
)
from .geometry import (  # noqa: F401
    compute_efcs_to_tdcs_rotations,
    compute_normal_vectors,
    compute_projection_transforms,
    strain_to_stress,
)



from setuptools import setup

version = open("VERSION").read()

description = open("README.md").read()

setup(
    packages=["cutde"],
    install_requires=[],
    zip_safe=False,
    include_package_data=True,
    name="cutde",
    version=version,
    description="130 million TDEs per second, Python + CUDA TDEs from Nikkhoo and Walter 2015",  # noqa:E501
    long_description=description,
    long_description_content_type="text/markdown",
    url="https://github.com/tbenthompson/cutde",
    author="T. Ben Thompson",
    author_email="t.ben.thompson@gmail.com",
    license="MIT",
    platforms=["any"],
)
